passwd_gen
⚠️ DISCLAIMER ⚠️
This is a testing/educational package ONLY. It provides NO GUARANTEE of safety, security, or correctness of any kind. This entire package was written by AI and should be treated as such. Do not use for production purposes or in any security-critical applications.
gleam add passwd_gen@1
import passwd_gen
pub fn main() -> Nil {
// TODO: An example of the project in use
}
Further documentation can be found at https://hexdocs.pm/passwd_gen.
Development
gleam run # Run the project
gleam test # Run the tests